@@ -2,7 +2,7 @@
 # Copyright 2020, Octoboxy LLC.  All Rights Reserved.
 
 
-from .enums       import Enum
+from .enums       import Enum, EnumOption
 
 from .registry    import Registry
 
