@@ -21,14 +21,6 @@ def MakeLeftRightString(left, right, width=40, stepping=40):
 #
 
 
-class MasterContext(base.TestModuleContext):
-  ''' Ensures our patterns get initialized. '''
-
-  def SetUp(self):
-    rightdown.InitializeAllPatterns()
-
-
-
 class OptionsContext(base.TestContext):
   ''' A TestContext that sets up RightDownOptions for a test case. '''
 
